@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckFile;
 {
-  $Git::Hooks::CheckFile::VERSION = '1.2.1';
+  $Git::Hooks::CheckFile::VERSION = '1.3.0';
 }
 # ABSTRACT: Git::Hooks plugin for checking files
 
@@ -52,7 +52,8 @@ sub check_new_files {
                     and next;
 
             # interpolate filename in $command
-            (my $cmd = $command) =~ s/\{\}/"'" . $tmp->filename() . "'"/eg;
+            my $tmpfile = $tmp->filename;
+            (my $cmd = $command) =~ s/\{\}/\'$tmpfile\'/g;
 
             # execute command and update $errors
             my $saved_output = redirect_output();
@@ -62,14 +63,19 @@ sub check_new_files {
                 $command =~ s/\{\}/\'$file\'/g;
                 my $message = do {
                     if ($exit == -1) {
-                        "'$command' failed to execute: $!";
+                        "command '$command' could not be executed: $!";
                     } elsif ($exit & 127) {
-                        sprintf("'%s' died with signal %d, %s coredump",
+                        sprintf("command '%s' was killed by signal %d, %s coredump",
                                 $command, ($exit & 127), ($exit & 128) ? 'with' : 'without');
                     } else {
-                        sprintf("'%s' failed (exit = %d)", $command, $exit >> 8);
+                        sprintf("command '%s' failed with exit code %d", $command, $exit >> 8);
                     }
                 };
+
+                # Replace any instance of the $tmpfile name in the output by
+                # $file to avoid confounding the user.
+                $output =~ s/\Q$tmpfile\E/$file/g;
+
                 $git->error($PKG, $message, $output);
                 ++$errors;
             } else {
@@ -135,7 +141,7 @@ Git::Hooks::CheckFile - Git::Hooks plugin for checking files
 
 =head1 VERSION
 
-version 1.2.1
+version 1.3.0
 
 =head1 DESCRIPTION
 
